Solar Orbiter EPD Loader Documentation
-----------------------------

This is the documentation for solo-epd-loader.

.. toctree::
   :maxdepth: 2
   :caption: Contents:


..
	Indices and tables
	==================
..
	* :ref:`genindex`
	* :ref:`modindex`
	* :ref:`search`


.. autofunction:: solo_epd_loader.epd_load


.. autofunction:: solo_epd_loader.get_available_soar_files
